@@ -1,9 +1,18 @@
 from jobqueues.celeryfiles.celery import app
+from celery.exceptions import SoftTimeLimitExceeded
+import psutil
+
+
+def kill(proc_pid):
+    process = psutil.Process(proc_pid)
+    for proc in process.children(recursive=True):
+        proc.kill()
+    process.kill()
 
 
 @app.task
 def run_simulation(folder, deviceid, sentinel, datadir, copyextensions, jobname=None):
-    from subprocess import call
+    import subprocess
     import os
     import time
 
@@ -15,18 +24,21 @@ def run_simulation(folder, deviceid, sentinel, datadir, copyextensions, jobname=
     # Sleep for a short bit so that the OS can pick up on the new file before executing it
     time.sleep(0.2)
 
+    process = None
     try:
         with open(stdfile, "a") as fout:
-            call(
-                ["/bin/sh", jobsh], stdout=fout, stderr=fout,
+            process = subprocess.Popen(
+                ["/bin/sh", jobsh], stdout=fout, stderr=fout, shell=False
             )
-        # logger.debug(ret)
+            _ = process.communicate()
+    except SoftTimeLimitExceeded:
+        # The SoftTimeLimitExceeded exception is a hack because SIGTERM doesn't work in Celery. See celeryqueue.py comment.
+        if process is not None:
+            kill(process.pid)
+        print(f"Job {jobname} has been cancelled by the user")
     except Exception as e:
-        # logger.error("Error in simulation {}. {}".format(folder, e))
         raise e
 
-    # logger.info("Completed " + folder)
-
 
 def _createJobScript(
     fname, workdir, runsh, deviceid, sentinel, datadir, copyextensions
@@ -35,9 +47,8 @@ def _createJobScript(
 
     with open(fname, "w") as f:
         f.write("#!/bin/bash\n\n")
-        # Trap kill signals to create sentinel file
         f.write(
-            '\ntrap "touch {}" EXIT SIGTERM\n'.format(
+            '\ntrap "touch {}" EXIT SIGTERM SIGINT\n'.format(
                 os.path.normpath(os.path.join(workdir, sentinel))
             )
         )
